@@ -93,7 +93,7 @@ def find_initd_dir():
       initdDir = os.path.realpath("/etc/init.d")
     else:
       initdDir = "/etc/init.d"
-  elif os.path.exists("/etc/rc.d./init.d"):
+  elif os.path.exists("/etc/rc.d/init.d"):
     initdDir = "/etc/rc.d/init.d"
   else:
     print("Unable to locate init.d directory! Exiting...", file=sys.stderr)
@@ -137,7 +137,7 @@ def get_matrix(initdDir, debug):
   return matrix
 
 def get_prog_ver(strprogram):
-  progver = strprogram + " " + " (LSB-Tools-0.8)"
+  progver = strprogram + " " + " (LSB-Tools-0.9)"
   return progver
 
 def install_font(argobject):
